from getDateParams import getDateParams


def formatTimestamp(timestamp=None):
    date_params = getDateParams(timestamp)
    return f"{date_params['year']}{date_params['month']}{date_params['day']}/{date_params['hour']}{date_params['minutes']}{date_params['seconds']}"



from .index import EchorLogger, echorLogger

# You can specify which symbols should be exposed when users do "from package import *"
__all__ = ['EchorLogger', 'echorLogger']

# Optionally, you can add package metadata
__version__ = '0.1.0'


from datetime import datetime


def convert_to_two_digit(digit):
    return f"{digit:02}"


def getDateParams(given_date=None):
    date = given_date or datetime.utcnow()
    month = convert_to_two_digit(date.month)
    day = convert_to_two_digit(date.day)
    year = date.year
    seconds = convert_to_two_digit(date.second)
    minutes = convert_to_two_digit(date.minute)
    hour = convert_to_two_digit(date.hour)

    return {
        "year": year,
        "month": month,
        "day": day,
        "seconds": seconds,
        "minutes": minutes,
        "hour": hour,
    }



import json
import os
import platform
from datetime import datetime

from dotenv import load_dotenv

from util.formatTimestamp import formatTimestamp

load_dotenv()

SERVICE_NAME = os.getenv('SERVICE_NAME', 'unknown-service')


def log_error(request, error_tags, data, error=None):
    timestamp = formatTimestamp(request.get('info', {}).get('received'))
    hostname = platform.node()
    process_id = os.getpid()
    machine_id = f"{int(datetime.utcnow().timestamp())}:{hostname}:{process_id}"
    tags = list(set(['ERROR'] + error_tags))
    correlations = {
        "user-agent": request['headers'].get('user-agent', 'unknown'),
        "x-correlation-id": request.get('correlationId', 'unknown'),
        "x-trace-id": request.get('traceId', 'unknown'),
        "service": SERVICE_NAME
    }

    log_data = {
        "timeStamp": timestamp,
        "subject": request.get('auth', {}).get('credentials', {}).get('sub'),
        "statusCode": data.get('statusCode'),
        "error": str(error) if error else data.get('error'),
        "message": data.get('message'),
        "errorCode": data.get('errorCode'),
        "method": request.get('method'),
        "uri": request.get('url'),
        "responseTime": data.get('responseTime')
    }

    print(
        f"{timestamp}, ({machine_id}) [{','.join(tags)}], {{\"correlations\": {json.dumps(correlations)}}}, data: {json.dumps(log_data)}")



from .logError import log_error
from .logSuccess import log_success, log_warn


class EchorLogger:
    def info(self, *args, **kwargs):
        log_success(*args, **kwargs)

    def warn(self, *args, **kwargs):
        log_warn(*args, **kwargs)

    def error(self, *args, **kwargs):
        log_error(*args, **kwargs)


echorLogger = EchorLogger()
